==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_applications/html_web_applications/search/all_0.js <==
var searchData=
[
  ['a_0',['a',['../group__API__Performance__Model.html#ab718a53c300f99766bdc42ca1909b49b',1,'starpu_perfmodel_regression_model']]],
  ['a_20stencil_20application_1',['A Stencil Application',['../StencilApplication.html',1,'']]],
  ['acked_5fworkers_2',['acked_workers',['../group__API__SC__Hypervisor.html#a829c79920efa453ee18491e8a85c1ff6',1,'sc_hypervisor_resize_ack']]],
  ['acquire_5fdata_5fend_5ftime_3',['acquire_data_end_time',['../group__API__Profiling.html#a0a43cc6fa5233d8d7e7ab0821607068c',1,'starpu_profiling_task_info']]],
  ['acquire_5fdata_5fstart_5ftime_4',['acquire_data_start_time',['../group__API__Profiling.html#a8f1fe52f21a7fc58860cf2f163ec868a',1,'starpu_profiling_task_info']]],
  ['act_5fhypervisor_5fmutex_5',['act_hypervisor_mutex',['../group__API__SC__Hypervisor__usage.html#gaf192fa1a6a02127cab3482459235799a',1,'sc_hypervisor.h']]],
  ['add_6',['add',['../group__API__Workers__Properties.html#ae039a760cdd80c0d91bcc4c4da9ebb74',1,'starpu_worker_collection']]],
  ['add_5fchild_7',['add_child',['../group__API__Modularized__Scheduler.html#a27af06d3f659a32cb4f3b9599fba00d8',1,'starpu_sched_component']]],
  ['add_5fworkers_8',['add_workers',['../group__API__Scheduling__Policy.html#a44e18efefc5e383997cc5684e014bd82',1,'starpu_sched_policy']]],
  ['all_5fcallback_5ftime_9',['all_callback_time',['../group__API__Profiling.html#a595e50d7029c774d275a4c60f16a0ada',1,'starpu_profiling_worker_info']]],
  ['all_5fexecuting_5ftime_10',['all_executing_time',['../group__API__Profiling.html#a67bee4aeadbec19556780f8328110957',1,'starpu_profiling_worker_info']]],
  ['all_5fscheduling_5ftime_11',['all_scheduling_time',['../group__API__Profiling.html#a4d1622e57181ef92126d0f100f9316bd',1,'starpu_profiling_worker_info']]],
  ['all_5fsleeping_5ftime_12',['all_sleeping_time',['../group__API__Profiling.html#a89ac253d44d475a9d2dfcb9153bd4b3a',1,'starpu_profiling_worker_info']]],
  ['all_5fwaiting_5ftime_13',['all_waiting_time',['../group__API__Profiling.html#a2c480622424a849f893cd322549642a5',1,'starpu_profiling_worker_info']]],
  ['alloc_14',['alloc',['../group__API__Out__Of__Core.html#a26b68767ae4037038eb72413aefd0420',1,'starpu_disk_ops']]],
  ['alloc_5fcompare_15',['alloc_compare',['../group__API__Data__Interfaces.html#a223bf2a2e0fe3a2c8042bdb90605c24d',1,'starpu_data_interface_ops']]],
  ['alloc_5ffootprint_16',['alloc_footprint',['../group__API__Data__Interfaces.html#abc69fa030b4398af1663af656d91c2c5',1,'starpu_data_interface_ops']]],
  ['allocate_5fdata_5fon_5fnode_17',['allocate_data_on_node',['../group__API__Data__Interfaces.html#afb8adfbac498be2eb6a587460f161e73',1,'starpu_data_interface_ops']]],
  ['allocsize_18',['allocsize',['../group__API__Data__Interfaces.html#a3ced8c019dfa184f17be42f9da9ca6e9',1,'starpu_matrix_interface::allocsize()'],['../group__API__Data__Interfaces.html#ade38975067536d0e2c8ff5e9480fa6fb',1,'starpu_ndim_interface::allocsize()'],['../group__API__Data__Interfaces.html#abccb7b1d3e85a19d010bec0e2202284f',1,'starpu_vector_interface::allocsize()']]],
  ['alpha_19',['alpha',['../group__API__Performance__Model.html#afb6b1e89bf7820131bddf970bb0df58b',1,'starpu_perfmodel_regression_model']]],
  ['any_5fto_5fany_20',['any_to_any',['../group__API__Data__Interfaces.html#add029fa5a3dc52c964587d97aca34263',1,'starpu_data_copy_methods']]],
  ['arch_5fcost_5ffunction_21',['arch_cost_function',['../group__API__Performance__Model.html#a4efccf0f3badb8eb35a07704b0e3ef01',1,'starpu_perfmodel']]],
  ['async_5ffull_5fread_22',['async_full_read',['../group__API__Out__Of__Core.html#af53a6785b2579883d976f756e2000a06',1,'starpu_disk_ops']]],
  ['async_5ffull_5fwrite_23',['async_full_write',['../group__API__Out__Of__Core.html#aa2a04016101ab8a46f6b22feb82676b5',1,'starpu_disk_ops']]],
  ['async_5fread_24',['async_read',['../group__API__Out__Of__Core.html#a34a70d305e32a3d944f5fefa8ca08183',1,'starpu_disk_ops']]],
  ['async_5fwrite_25',['async_write',['../group__API__Out__Of__Core.html#a7a5ba5bb81c7f6350135640b14880de9',1,'starpu_disk_ops']]]
];

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_applications/html_web_applications/search/all_0.js <==
var searchData=
[
  ['a_0',['a',['../group__API__Performance__Model.html#ab718a53c300f99766bdc42ca1909b49b',1,'starpu_perfmodel_regression_model']]],
  ['a_20stencil_20application_1',['A Stencil Application',['../StencilApplication.html',1,'']]],
  ['acked_5fworkers_2',['acked_workers',['../group__API__SC__Hypervisor.html#a829c79920efa453ee18491e8a85c1ff6',1,'sc_hypervisor_resize_ack']]],
  ['acquire_5fdata_5fend_5ftime_3',['acquire_data_end_time',['../group__API__Profiling.html#a0a43cc6fa5233d8d7e7ab0821607068c',1,'starpu_profiling_task_info']]],
  ['acquire_5fdata_5fstart_5ftime_4',['acquire_data_start_time',['../group__API__Profiling.html#a8f1fe52f21a7fc58860cf2f163ec868a',1,'starpu_profiling_task_info']]],
  ['act_5fhypervisor_5fmutex_5',['act_hypervisor_mutex',['../group__API__SC__Hypervisor__usage.html#gaf192fa1a6a02127cab3482459235799a',1,'sc_hypervisor.h']]],
  ['add_6',['add',['../group__API__Workers.html#ae039a760cdd80c0d91bcc4c4da9ebb74',1,'starpu_worker_collection']]],
  ['add_5fchild_7',['add_child',['../group__API__Modularized__Scheduler.html#a27af06d3f659a32cb4f3b9599fba00d8',1,'starpu_sched_component']]],
  ['add_5fworkers_8',['add_workers',['../group__API__Scheduling__Policy.html#a44e18efefc5e383997cc5684e014bd82',1,'starpu_sched_policy']]],
  ['all_5fcallback_5ftime_9',['all_callback_time',['../group__API__Profiling.html#a595e50d7029c774d275a4c60f16a0ada',1,'starpu_profiling_worker_info']]],
  ['all_5fexecuting_5ftime_10',['all_executing_time',['../group__API__Profiling.html#a67bee4aeadbec19556780f8328110957',1,'starpu_profiling_worker_info']]],
  ['all_5fscheduling_5ftime_11',['all_scheduling_time',['../group__API__Profiling.html#a4d1622e57181ef92126d0f100f9316bd',1,'starpu_profiling_worker_info']]],
  ['all_5fsleeping_5ftime_12',['all_sleeping_time',['../group__API__Profiling.html#a89ac253d44d475a9d2dfcb9153bd4b3a',1,'starpu_profiling_worker_info']]],
  ['all_5fwaiting_5ftime_13',['all_waiting_time',['../group__API__Profiling.html#a2c480622424a849f893cd322549642a5',1,'starpu_profiling_worker_info']]],
  ['alloc_14',['alloc',['../group__API__Out__Of__Core.html#a61b0e51977bdc6cc20d75f7c3ff2d614',1,'starpu_disk_ops']]],
  ['alloc_5fcompare_15',['alloc_compare',['../group__API__Data__Interfaces.html#a223bf2a2e0fe3a2c8042bdb90605c24d',1,'starpu_data_interface_ops']]],
  ['alloc_5ffootprint_16',['alloc_footprint',['../group__API__Data__Interfaces.html#abc69fa030b4398af1663af656d91c2c5',1,'starpu_data_interface_ops']]],
  ['allocate_5fdata_5fon_5fnode_17',['allocate_data_on_node',['../group__API__Data__Interfaces.html#afb8adfbac498be2eb6a587460f161e73',1,'starpu_data_interface_ops']]],
  ['allocsize_18',['allocsize',['../group__API__Data__Interfaces.html#a3ced8c019dfa184f17be42f9da9ca6e9',1,'starpu_matrix_interface::allocsize()'],['../group__API__Data__Interfaces.html#ade38975067536d0e2c8ff5e9480fa6fb',1,'starpu_ndim_interface::allocsize()'],['../group__API__Data__Interfaces.html#abccb7b1d3e85a19d010bec0e2202284f',1,'starpu_vector_interface::allocsize()']]],
  ['alpha_19',['alpha',['../group__API__Performance__Model.html#afb6b1e89bf7820131bddf970bb0df58b',1,'starpu_perfmodel_regression_model']]],
  ['any_5fto_5fany_20',['any_to_any',['../group__API__Data__Interfaces.html#add029fa5a3dc52c964587d97aca34263',1,'starpu_data_copy_methods']]],
  ['arch_5fcost_5ffunction_21',['arch_cost_function',['../group__API__Performance__Model.html#a4efccf0f3badb8eb35a07704b0e3ef01',1,'starpu_perfmodel']]],
  ['async_5ffull_5fread_22',['async_full_read',['../group__API__Out__Of__Core.html#ab2317c0bff32b2b338632c70d56466c6',1,'starpu_disk_ops']]],
  ['async_5ffull_5fwrite_23',['async_full_write',['../group__API__Out__Of__Core.html#a67804045d2c3a3e240ec152090885853',1,'starpu_disk_ops']]],
  ['async_5fread_24',['async_read',['../group__API__Out__Of__Core.html#ae0d4c45de6fe688d86f234884d26f4e0',1,'starpu_disk_ops']]],
  ['async_5fwrite_25',['async_write',['../group__API__Out__Of__Core.html#a217c4a50625fa3489ff9fde9259b020e',1,'starpu_disk_ops']]]
];
